summaryrefslogtreecommitdiffstats
path: root/kdeui/kbuttonbox.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kdeui/kbuttonbox.cpp
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kbuttonbox.cpp')
-rw-r--r--kdeui/kbuttonbox.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdeui/kbuttonbox.cpp b/kdeui/kbuttonbox.cpp
index dc5f2674b..eb0e27827 100644
--- a/kdeui/kbuttonbox.cpp
+++ b/kdeui/kbuttonbox.cpp
@@ -20,7 +20,7 @@
/*
* KButtonBox class
*
* A container widget for buttons. Uses Qt tqlayout control to place the
* buttons, can handle both vertical and horizontal button placement.
*
* HISTORY
@@ -39,7 +39,7 @@
* which makes the buttons look better.
*
* 01/17/98 Mario Weilguni <mweilguni@sime.com>
* Fixed a bug in tqsizeHint()
* Improved the handling of Motif default buttons
*
* 01/09/98 Mario Weilguni <mweilguni@sime.com>
@@ -160,7 +160,7 @@ void KButtonBox::addStretch(int scale) {
}
}
-void KButtonBox::tqlayout() {
+void KButtonBox::layout() {
// resize all buttons
const TQSize bs = bestButtonSize();
@@ -178,7 +178,7 @@ void KButtonBox::tqlayout() {
++itr;
}
- setMinimumSize(tqsizeHint());
+ setMinimumSize(sizeHint());
}
void KButtonBox::placeButtons() {
@@ -300,7 +300,7 @@ TQSize KButtonBox::bestButtonSize() const {
return s;
}
-TQSize KButtonBox::tqsizeHint() const {
+TQSize KButtonBox::sizeHint() const {
unsigned int dw;
if(data->buttons.isEmpty())
@@ -355,8 +355,8 @@ TQSizePolicy KButtonBox::sizePolicy() const
* as minimum width
*/
TQSize KButtonBox::buttonSizeHint(TQPushButton *b) const {
- TQSize s = b->tqsizeHint();
- const TQSize ms = b->tqminimumSize();
+ TQSize s = b->sizeHint();
+ const TQSize ms = b->minimumSize();
if(s.width() < minButtonWidth)
s.setWidth(minButtonWidth);
@@ -20,7 +20,7 @@
* KButtonBox class
*
- * A container widget for buttons. Uses Qt tqlayout control to place the
+ * A container widget for buttons. Uses Qt layout control to place the
* buttons, can handle both vertical and horizontal button placement.
*
@@ -39,7 +39,7 @@
*
* 01/17/98 Mario Weilguni <mweilguni@sime.com>
- * Fixed a bug in tqsizeHint()
+ * Fixed a bug in sizeHint()
* Improved the handling of Motif default buttons
*